# WebAuth

Lightweight Python web framework

<img src="https://img.shields.io/pypi/v/webauth.svg" />
<img src="https://img.shields.io/badge/license-MIT-green.svg" />
<img src="https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue.svg" />

## Why

WebAuth is a lightweight framework based on Flask and AuthLib. Our goal is only
to have functions for:

* Basic user management
* User authentication

## Documentation

https://webauth.readthedocs.io/

## Installation

```
pip3 install webauth
```
